@@ -10,17 +10,15 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from __future__ import division
-from math import ceil
 from datetime import datetime
+from math import ceil
 
-from nose.tools import assert_equal
+import pytest
 
-from tests import random_chars
-from tests import BaseSessionTest
-from botocore.stub import Stubber, StubAssertionError
-from botocore.paginate import TokenDecoder, TokenEncoder
 from botocore.compat import six
+from botocore.paginate import TokenDecoder, TokenEncoder
+from botocore.stub import StubAssertionError, Stubber
+from tests import BaseSessionTest, random_chars
 
 
 class TestRDSPagination(BaseSessionTest):
@@ -78,8 +76,9 @@ class TestAutoscalingPagination(BaseSessionTest):
         self.stubber = Stubber(self.client)
         self.stubber.activate()
 
-    def _setup_scaling_pagination(self, page_size=200, max_items=100,
-                                 total_items=600):
+    def _setup_scaling_pagination(
+        self, page_size=200, max_items=100, total_items=600
+    ):
         """
         Add to the stubber to test paginating describe_scaling_activities.
 
@@ -173,22 +172,63 @@ class TestAutoscalingPagination(BaseSessionTest):
         self.assertEqual(len(all_results), total_items)
 
 
-def test_token_encoding():
-    cases = [
+class TestCloudwatchLogsPagination(BaseSessionTest):
+    def setUp(self):
+        super(TestCloudwatchLogsPagination, self).setUp()
+        self.region = 'us-west-2'
+        self.client = self.session.create_client(
+            'logs', self.region, aws_secret_access_key='foo',
+            aws_access_key_id='bar', aws_session_token='baz'
+        )
+        self.stubber = Stubber(self.client)
+        self.stubber.activate()
+
+    def test_token_with_triple_underscores(self):
+        response = {
+            'events': [{
+                'logStreamName': 'foobar',
+                'timestamp': 1560195817,
+                'message': 'a thing happened',
+                'ingestionTime': 1560195817,
+                'eventId': 'foo',
+            }],
+            'searchedLogStreams': [{
+                'logStreamName': 'foobar',
+                'searchedCompletely': False,
+            }],
+        }
+        group_name = 'foo'
+        token = 'foo___bar'
+        expected_args = {
+            'logGroupName': group_name,
+            'nextToken': token,
+        }
+        self.stubber.add_response('filter_log_events', response, expected_args)
+        paginator = self.client.get_paginator('filter_log_events')
+        pages = paginator.paginate(
+            PaginationConfig={
+                'MaxItems': 1,
+                'StartingToken': token,
+            },
+            logGroupName=group_name,
+        )
+        result = pages.build_full_result()
+        self.assertEqual(len(result['events']), 1)
+
+
+@pytest.mark.parametrize(
+    "token_dict",
+    (
         {'foo': 'bar'},
         {'foo': b'bar'},
         {'foo': {'bar': b'baz'}},
         {'foo': ['bar', b'baz']},
         {'foo': b'\xff'},
         {'foo': {'bar': b'baz', 'bin': [b'bam']}},
-    ]
-
-    for token_dict in cases:
-        yield assert_token_encodes_and_decodes, token_dict
-
-
-def assert_token_encodes_and_decodes(token_dict):
+    )
+)
+def test_token_encoding(token_dict):
     encoded = TokenEncoder().encode(token_dict)
     assert isinstance(encoded, six.string_types)
     decoded = TokenDecoder().decode(encoded)
-    assert_equal(decoded, token_dict)
+    assert decoded == token_dict
