@@ -20,10 +20,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 #
-from tests import unittest
 from botocore.compat import six
-from botocore.docs.bcdoc.style import ReSTStyle
 from botocore.docs.bcdoc.restdoc import ReSTDocument
+from botocore.docs.bcdoc.style import ReSTStyle
+from tests import unittest
 
 
 class TestStyle(unittest.TestCase):
@@ -47,11 +47,23 @@ class TestStyle(unittest.TestCase):
         style.bold('foobar')
         self.assertEqual(style.doc.getvalue(), six.b('**foobar** '))
 
+    def test_empty_bold(self):
+        style = ReSTStyle(ReSTDocument())
+        style.start_b()
+        style.end_b()
+        self.assertEqual(style.doc.getvalue(), six.b(''))
+
     def test_italics(self):
         style = ReSTStyle(ReSTDocument())
         style.italics('foobar')
         self.assertEqual(style.doc.getvalue(), six.b('*foobar* '))
 
+    def test_empty_italics(self):
+        style = ReSTStyle(ReSTDocument())
+        style.start_i()
+        style.end_i()
+        self.assertEqual(style.doc.getvalue(), six.b(''))
+
     def test_p(self):
         style = ReSTStyle(ReSTDocument())
         style.start_p()
@@ -64,6 +76,12 @@ class TestStyle(unittest.TestCase):
         style.code('foobar')
         self.assertEqual(style.doc.getvalue(), six.b('``foobar`` '))
 
+    def test_empty_code(self):
+        style = ReSTStyle(ReSTDocument())
+        style.start_code()
+        style.end_code()
+        self.assertEqual(style.doc.getvalue(), six.b(''))
+
     def test_h1(self):
         style = ReSTStyle(ReSTDocument())
         style.h1('foobar fiebaz')
@@ -317,9 +335,23 @@ class TestStyle(unittest.TestCase):
         self.assertEqual(style.doc.getvalue(),
                          six.b('`MyLink <http://example.com/foo>`_'))
 
-
     def test_external_link_in_man_page(self):
         style = ReSTStyle(ReSTDocument())
         style.doc.target = 'man'
         style.external_link('MyLink', 'http://example.com/foo')
         self.assertEqual(style.doc.getvalue(), six.b('MyLink'))
+
+    def test_internal_link(self):
+        style = ReSTStyle(ReSTDocument())
+        style.doc.target = 'html'
+        style.internal_link('MyLink', '/index')
+        self.assertEqual(
+            style.doc.getvalue(),
+            six.b(':doc:`MyLink </index>`')
+        )
+
+    def test_internal_link_in_man_page(self):
+        style = ReSTStyle(ReSTDocument())
+        style.doc.target = 'man'
+        style.internal_link('MyLink', '/index')
+        self.assertEqual(style.doc.getvalue(), six.b('MyLink'))
